package net.sf.daileon.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Indicates the method that keeps the annotations that correspond to a domain
 * annotation at method level.
 * 
 * @author Roberto Perillo
 * @version 1.0 01/01/2010
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.ANNOTATION_TYPE)
public @interface MethodTemplate {

    /**
     * Informs the name of the class that keeps the annotations that correspond
     * to a domain annotation at method level. The value indicated must be fully
     * qualified.
     * 
     * @return The name of the class.
     */
    public abstract String annotatedClass();

    /**
     * Informs the name of the actual method that keeps the annotations that
     * correspond to the domain annotation. The name of the method must be
     * unique in the class.
     * 
     * @return The name of the method.
     */
    public abstract String method();
}