package net.sf.daileon.notsupported;

import org.objectweb.asm.ClassVisitor;

/**
 * Default implementation of the <code>AbstractAnnotationsReplacer</code>. Its
 * fully-qualified name may be indicated in the XML configuration file, in order
 * to indicate that the domain annotations should not be kept in the final
 * bytecode.
 * 
 * @author Roberto Perillo
 * @version 1.0 01/01/2010
 */
public class DomainAnnotationsDiscarder extends AbstractAnnotationsReplacer {

    /**
     * Class constructor.
     * 
     * @param classVisitor
     *            The <a href=
     *            "http://asm.ow2.org/asm153/javadoc/user/org/objectweb/asm/ClassVisitor.html"
     *            >ClassVisitor</a> object, provided by the
     *            {@link ClassTransformer#transform(String, String)} method.
     */
    public DomainAnnotationsDiscarder(ClassVisitor classVisitor) {
        super(classVisitor);
    }

    /**
     * Indicates that the domain annotations shall not be kept in the final
     * bytecode.
     * 
     * @return <code>false</code>, in order to indicate that the domain
     *         annotations shall not be kept in the final bytecode.
     */
    @Override
    protected boolean keepDomainAnnotations() {
        return false;
    }

}