package net.sf.daileon.notsupported;

import java.util.Iterator;
import java.util.List;

/**
 * The <code>DomainAnnotationsHandler</code> class is responsible for starting
 * the process of transforming each class indicated in the XML configuration
 * file.
 * 
 * @author Roberto Perillo
 * @version 1.0 01/01/2010
 * 
 */
public class DomainAnnotationsHandler {

    /**
     * Default class constructor.
     */
    public DomainAnnotationsHandler() {
        super();
    }

    /**
     * Triggers the process of translating the domain annotations of each domain
     * annotation of each class indicated in the XML configuration file, when
     * Daileon is run.
     * 
     * @param path
     *            The root directory of the classes, excluding their packages.
     * @param classes
     *            The <code>List&lt;String&gt;</code> containing the
     *            fully-qualified name of all classes that contain domain
     *            annotations to be translated.
     */
    public void makeTransformations(String path, List<String> classes) {
        if (classes == null) {
            final String message = "The domain annotations handler was not "
                    + "initialized correctly.";
            throw new RuntimeException(message);
        }

        final Iterator<String> iterator = classes.iterator();
        ClassTransformer transformer = new ClassTransformer();

        while (iterator.hasNext()) {
            String annotatedClass = iterator.next();
            transformer.transform(path, annotatedClass);
        }
    }
}