package net.sf.daileon.notsupported;

/**
 * The <code>ElementBase</code> class represents the base of class elements,
 * such as fields or methods.
 * 
 * @author Roberto Perillo
 * @version 1.0 01/01/2010
 */
abstract class ElementBase extends ElementRoot {

    /** The access modifier of the element */
    private int access;

    /** The name of the element */
    private String name;

    /** The description of the element */
    private String desc;

    /**
     * Gets the access modifier of the given element.
     * 
     * @return The access modifier of the given element.
     */
    int getAccess() {
        return access;
    }

    /**
     * Sets the access modifier of the given element.
     * 
     * @param access
     *            The access modifier of the given element.
     */
    void setAccess(int access) {
        this.access = access;
    }

    /**
     * Gets the name of the given element.
     * 
     * @return The name of the given element.
     */
    String getName() {
        return name;
    }

    /**
     * Sets the name of the given element.
     * 
     * @param name
     *            The name of the given element.
     */
    void setName(String name) {
        this.name = name;
    }

    /**
     * Gets the description of the given element.
     * 
     * @return The description of the given element.
     */
    String getDesc() {
        return desc;
    }

    /**
     * Sets the description of the given element.
     * 
     * @param desc
     *            The description of the given element.
     */
    void setDesc(String desc) {
        this.desc = desc;
    }

    /** {@inheritDoc} */
    @Override
    public int hashCode() {
        int hash = (name != null) ? name.hashCode() : 0;
        hash += (desc != null) ? desc.hashCode() : 0;
        hash += (getClassName() != null) ? getClassName().hashCode() : 0;
        return hash;
    }

    /** {@inheritDoc} */
    @Override
    public boolean equals(Object element) {
        if (this == element) {
            return true;
        } else {
            if (element instanceof ElementBase) {
                ElementBase info = (ElementBase) element;
                String className = info.getClassName();
                if (className.equals(getClassName())
                        && info.getName().equals(name)
                        && info.getDesc().equals(desc)) {
                    return true;
                }
            }
        }
        return false;
    }

    /** {@inheritDoc} */
    @Override
    public String toString() {
        String description = "Name: " + name + "; description: " + desc;
        return description;
    }
}