package net.sf.daileon.notsupported;

import org.objectweb.asm.Attribute;

/**
 * The <code>ElementRoot</code> class represents the root of class elements. It
 * simply holds the name of the class and its annotations.
 * 
 * @author Roberto Perillo
 * @version 1.0 01/01/2010
 */
class ElementRoot {

    /** The name of the class */
    private String className;

    /** The <code>Attribute</code> (or annotations) that annotate the class */
    private Attribute attribute;

    /**
     * Class constructor.
     */
    ElementRoot() {
        super();
    }

    /**
     * Gets the name of the class.
     * 
     * @return The name of the class.
     */
    String getClassName() {
        return className;
    }

    /**
     * Sets the name of the class.
     * 
     * @param className
     *            The name of the class.
     */
    void setClassName(String className) {
        this.className = className;
    }

    /**
     * Gets the <code>Attribute</code> (or annotations) of the class.
     * 
     * @return The <code>Attribute</code> (or annotations) of the class.
     */
    Attribute getAttribute() {
        return attribute;
    }

    /**
     * Sets the <code>Attribute</code> (or annotations) of the class.
     * 
     * @param attribute
     *            The <code>Attribute</code> (or annotations) of the class.
     */
    void setAttribute(Attribute attribute) {
        this.attribute = attribute;
    }

    /** {@inheritDoc} */
    @Override
    public int hashCode() {
        return (className != null ? className.hashCode() : 0);
    }

    /** {@inheritDoc} */
    @Override
    public boolean equals(Object object) {
        if (object == this) {
            return true;
        } else {
            if (object instanceof ElementRoot) {
                ElementRoot element = (ElementRoot) object;
                String className = element.getClassName();
                if (className != null && className.equals(this.className)) {
                    return true;
                }
            }
        }
        return false;
    }

    /** {@inheritDoc} */
    @Override
    public String toString() {
        String description = "Class name: " + className;
        return description;
    }

}