package net.sf.daileon.notsupported;

import org.objectweb.asm.Attribute;
import org.objectweb.asm.ClassVisitor;
import org.objectweb.asm.attrs.RuntimeVisibleAnnotations;

/**
 * The <code>TemplateAnnotationsCollector</code> is responsible for collecting
 * template annotations of a domain annotation, so that the elements indicated
 * by them can be read, and the domain annotation can be evaluated properly.
 * 
 * @author Roberto Perillo
 * @version 1.0 01/01/2010
 */
class TemplateAnnotationsCollector extends AbstractTemplateAnnotationsCollector {

    /**
     * Class constructor.
     * 
     * @param classVisitor
     *            The <a href=
     *            "http://asm.ow2.org/asm153/javadoc/user/org/objectweb/asm/ClassVisitor.html"
     *            >ClassVisitor</a> object that visits the class.
     */
    TemplateAnnotationsCollector(ClassVisitor classVisitor) {
        super(classVisitor);
    }

    /**
     * Visits the template annotation at class level and collects the
     * annotations that annotate the class indicated in it.
     */
    @Override
    public void visitAttribute(Attribute attribute) {
        if (attribute instanceof RuntimeVisibleAnnotations) {
            collectAnnotations(attribute);
        }
    }

}