package net.sf.daileon.xml;

import java.io.InputStream;
import java.io.OutputStream;

/**
 * The <code>XmlHandler</code> interface defines methods for serializing objects
 * to a particular {@link OutputStream}, as well as reading XML files and
 * returning objects equivalent to their structure.
 * 
 * @author Roberto Perillo
 * @version 01/01/2010
 */
public interface XmlHandler {

    /**
     * Serializes the content of a given object to an <code>OutputStream</code>.
     * 
     * @param bean
     *            The object to be serialized in form of XML file.
     * @param destiny
     *            The destination (as <code>OutputStream</code>) of the XML file
     *            to be serialized.
     * @param context
     *            The context of the XML file. For instance, for the
     *            {@link JaxbXmlHandler} implementation, the context is the
     *            package where the objects that represent the XML structure are
     *            located.
     * @throws XmlHandlerException
     *             If any problem occur when trying to serialize the object.
     */
    public void beanToXml(final Object bean, final OutputStream destiny,
            final String context) throws XmlHandlerException;

    /**
     * Retrieves the content of a given XML file as an <code>Object</code>.
     * 
     * @param source
     *            The XML file to be read, as <code>InputStream</code>.
     * @param context
     *            The context of the XML file. For instance, for the
     *            {@link JaxbXmlHandler} implementation, the context is the
     *            package where the objects that represent the XML structure are
     *            located.
     * @return The structure of the XML file as an <code>Object</code>.
     * @throws XmlHandlerException
     *             If any problem occur when trying to read the XML file and
     *             transform it to an <code>Object</code> representation.
     */
    public Object xmlToBean(final InputStream source, final String context)
            throws XmlHandlerException;
}