package net.sf.daileon.xml.items;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

/**
 * The <code>DaileonConfig</code> class represents the root element of the XML
 * configuration file, indicated in the command line when Daileon is run.<br />
 * A <code>DaileonConfig</code> object is mainly responsible for holding 2
 * objects, which represent respectively the <code>&lt;setup&gt;</code> and the
 * <code>&lt;domain-annotations&gt;</code> elements of the XML configuration
 * file.
 * 
 * @author Roberto Perillo
 * @version 1.0 01/01/2010
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "daileon-config", propOrder = {"setup", "domainAnnotations"})
@XmlRootElement(name = "daileon-config")
public class DaileonConfig {

    /** The <code>&lt;setup&gt;</code> structure of the XML configuration file */
    @XmlElement(name = "setup", required = true, nillable = false)
    private Setup setup;

    /**
     * The <code>&lt;domain-annotations&gt;</code> structure of the XML
     * configuration file
     */
    @XmlElement(name = "domain-annotations", required = true, nillable = false)
    private DomainAnnotations domainAnnotations;

    /**
     * Gets the object that represents the <code>&lt;setup&gt;</code> element of
     * the XML configuration file.
     * 
     * @return The object that represents the <code>&lt;setup&gt;</code> element
     *         of the XML configuration file.
     */
    public Setup getSetup() {
        return setup;
    }

    /**
     * Sets the object that represents the <code>&lt;setup&gt;</code> element of
     * the XML configuration file.
     * 
     * @param setup
     *            The object that represents the <code>&lt;setup&gt;</code>
     *            element of the XML configuration file.
     */
    public void setSetup(Setup setup) {
        this.setup = setup;
    }

    /**
     * Gets the object that represents the
     * <code>&lt;domain-annotations&gt;</code> element of the XML configuration
     * file.
     * 
     * @return The object that represents the
     *         <code>&lt;domain-annotations&gt;</code> element of the XML
     *         configuration file.
     */
    public DomainAnnotations getDomainAnnotations() {
        return domainAnnotations;
    }

    /**
     * Sets the object that represents the
     * <code>&lt;domain-annotations&gt;</code> element of the XML configuration
     * file.
     * 
     * @param domainAnnotations
     *            The object that represents the <code>&lt;setup&gt;</code>
     *            element of the XML configuration file.
     */
    public void setDomainAnnotations(DomainAnnotations domainAnnotations) {
        this.domainAnnotations = domainAnnotations;
    }

}