package net.sf.daileon.xml.items;

import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

/**
 * The <code>DomainAnnotations</code> class represents the
 * <code>&lt;domain-annotations&gt;</code> element of the XML configuration,
 * indicated in the command line when Daileon is run. file.
 * 
 * @author Roberto Perillo
 * @version 1.0 01/01/2010
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "domain-annotations", propOrder = "annotatedClass")
@XmlRootElement(name = "domain-annotations")
public class DomainAnnotations {

    /**
     * The <code>List&lt;String&gt;</code> of classes containing domain
     * annotations to be evaluated
     */
    @XmlElement(name = "annotated-class", required = true, nillable = false)
    private List<String> annotatedClass;

    /**
     * Gets the <code>List&lt;String&gt;</code> of classes that are annotated
     * with domain annotations to be evaluated.
     * 
     * @return The <code>List&lt;String&gt;</code> of classes that are annotated
     *         with domain annotations to be evaluated.
     */
    public List<String> getAnnotatedClasses() {
        return annotatedClass;
    }

    /**
     * Sets the <code>List&lt;String&gt;</code> of classes that are annotated
     * with domain annotations to be evaluated.
     * 
     * @param annotatedClass
     *            The <code>List&lt;String&gt;</code> of classes that are
     *            annotated with domain annotations to be evaluated.
     */
    public void setAnnotatedClasses(List<String> annotatedClass) {
        this.annotatedClass = annotatedClass;
    }

}