package net.sf.daileon.xml.items;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

/**
 * The <code>Setup</code> class represents the <code>&lt;setup&gt;</code>
 * element of the XML configuration, indicated in the command line when Daileon
 * is run. file.
 * 
 * @author Roberto Perillo
 * @version 1.0 01/01/2010
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "setup", propOrder = {"rootDirectory", "destinyDirectory",
        "strategyClass", "domainAnnotationsReplacer"})
@XmlRootElement(name = "setup")
public class Setup {

    /**
     * The root directory, where the original classes of the project are located
     */
    @XmlElement(name = "root-directory", required = true, nillable = false)
    private String rootDirectory;

    /**
     * The destiny directory, where the original compiled classes of the project
     * shall be copied to
     */
    @XmlElement(name = "destiny-directory", required = true, nillable = false)
    private String destinyDirectory;

    /** The <code>Strategy</code> object */
    @XmlElement(name = "strategy-class", required = false)
    private String strategyClass;

    /** The <code>AbstractAnnotationsReplacer</code> object */
    @XmlElement(name = "domain-annotations-replacer", required = false)
    private String domainAnnotationsReplacer;

    /**
     * Gets the root directory, which is the directory where the original
     * compiled classes of the project are located.
     * 
     * @return The root directory, which is the directory where the original
     *         compiled classes of the project are located.
     */
    public String getRootDirectory() {
        return rootDirectory;
    }

    /**
     * Sets the root directory, which is the directory where the original
     * compiled classes of the project are located.
     * 
     * @param rootDirectory
     *            The root directory, which is the directory where the original
     *            compiled classes of the project are located.
     */
    public void setRootDirectory(String rootDirectory) {
        this.rootDirectory = rootDirectory;
    }

    /**
     * Gets the destiny directory, which is the directory where the original
     * compiled classes of the project shall be copied to.
     * 
     * @return The destiny directory, which is the directory where the original
     *         compiled classes of the project shall be copied to.
     */
    public String getDestinyDirectory() {
        return destinyDirectory;
    }

    /**
     * Sets the destiny directory, which is the directory where the original
     * compiled classes of the project shall be copied to.
     * 
     * @param destinyDirectory
     *            The destiny directory, which is the directory where the
     *            original compiled classes of the project shall be copied to.
     */
    public void setDestinyDirectory(String destinyDirectory) {
        this.destinyDirectory = destinyDirectory;
    }

    /**
     * Gets the <code>Strategy</code> class.
     * 
     * @return The <code>Strategy</code> class.
     */
    public String getStrategyClass() {
        return strategyClass;
    }

    /**
     * Sets the <code>Strategy</code> fully-qualified name.
     * 
     * @param strategyClass
     *            The <code>Strategy</code> fully-qualified name.
     */
    public void setStrategyClass(String strategyClass) {
        this.strategyClass = strategyClass;
    }

    /**
     * Gets the <code>AbstractAnnotationsReplacer</code> fully-qualified name.
     * 
     * @return The <code>AbstractAnnotationsReplacer</code> fully-qualified
     *         name.
     */
    public String getDomainAnnotationsReplacer() {
        return domainAnnotationsReplacer;
    }

    /**
     * Sets the <code>AbstractAnnotationsReplacer</code> fully-qualified name.
     * 
     * @param domainAnnotationsReplacer
     *            The <code>AbstractAnnotationsReplacer</code> fully-qualified
     *            name.
     */
    public void setDomainAnnotationsReplacer(String domainAnnotationsReplacer) {
        this.domainAnnotationsReplacer = domainAnnotationsReplacer;
    }
}